.. bronx documentation master file, created by
   sphinx-quickstart on Wed Nov  2 14:34:54 2022.

Welcome to TNT's documentation (TheNamelistTool)!
=================================================

.. automodule:: thenamelisttool

Developpers' corner
-------------------

Here is a list sub-modules/packages:

.. autosummary::
   :toctree: _autosummary
   :template: autosummary/custom-module.tpl
   :recursive:

   thenamelisttool.config
   thenamelisttool.namadapter
   thenamelisttool.util
   thenamelisttool.entrypoints


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
